OUTPUT_SUMMARY = "s"
OUTPUT_LIST = "l"
CRAWL_MODE = "M"
MODE_SIMPLE = "s"
MODE_EXTENDED = "e"
HIT = "h"
LINK = "l"
